Documentation
¶
Overview ¶
Package theme defines how a Fyne app should look when rendered.
Index ¶
- Constants
- func AccountIcon() fyne.Resource
- func BackgroundColor() color.Colordeprecated
- func BrokenImageIcon() fyne.Resource
- func ButtonColor() color.Colordeprecated
- func CalendarIcon() fyne.Resource
- func CancelIcon() fyne.Resource
- func CaptionTextSize() float32
- func CheckButtonCheckedIcon() fyne.Resource
- func CheckButtonFillIcon() fyne.Resource
- func CheckButtonIcon() fyne.Resource
- func Color(name fyne.ThemeColorName) color.Color
- func ColorAchromaticIcon() fyne.Resource
- func ColorChromaticIcon() fyne.Resource
- func ColorForWidget(name fyne.ThemeColorName, w fyne.Widget) color.Color
- func ColorPaletteIcon() fyne.Resource
- func ComputerIcon() fyne.Resource
- func ConfirmIcon() fyne.Resource
- func ContentAddIcon() fyne.Resource
- func ContentClearIcon() fyne.Resource
- func ContentCopyIcon() fyne.Resource
- func ContentCutIcon() fyne.Resource
- func ContentPasteIcon() fyne.Resource
- func ContentRedoIcon() fyne.Resource
- func ContentRemoveIcon() fyne.Resource
- func ContentUndoIcon() fyne.Resource
- func Current() fyne.Theme
- func CurrentForWidget(w fyne.CanvasObject) fyne.Theme
- func DarkTheme() fyne.Themedeprecated
- func DefaultEmojiFont() fyne.Resource
- func DefaultSymbolFont() fyne.Resource
- func DefaultTextBoldFont() fyne.Resource
- func DefaultTextBoldItalicFont() fyne.Resource
- func DefaultTextFont() fyne.Resource
- func DefaultTextItalicFont() fyne.Resource
- func DefaultTextMonospaceFont() fyne.Resource
- func DefaultTheme() fyne.Theme
- func DeleteIcon() fyne.Resource
- func DesktopIcon() fyne.Resource
- func DisabledButtonColor() color.Colordeprecated
- func DisabledColor() color.Colordeprecated
- func DisabledTextColor() color.Colordeprecated
- func DocumentCreateIcon() fyne.Resource
- func DocumentIcon() fyne.Resource
- func DocumentPrintIcon() fyne.Resource
- func DocumentSaveIcon() fyne.Resource
- func DownloadIcon() fyne.Resource
- func ErrorColor() color.Colordeprecated
- func ErrorIcon() fyne.Resource
- func FileApplicationIcon() fyne.Resource
- func FileAudioIcon() fyne.Resource
- func FileIcon() fyne.Resource
- func FileImageIcon() fyne.Resource
- func FileTextIcon() fyne.Resource
- func FileVideoIcon() fyne.Resource
- func FocusColor() color.Colordeprecated
- func FolderIcon() fyne.Resource
- func FolderNewIcon() fyne.Resource
- func FolderOpenIcon() fyne.Resource
- func Font(style fyne.TextStyle) fyne.Resource
- func ForegroundColor() color.Colordeprecated
- func FromJSON(data string) (fyne.Theme, error)
- func FromJSONReader(r io.Reader) (fyne.Theme, error)
- func FromJSONReaderWithFallback(r io.Reader, fallback fyne.Theme) (fyne.Theme, error)
- func FromJSONWithFallback(data string, fallback fyne.Theme) (fyne.Theme, error)
- func FromLegacy(t fyne.LegacyTheme) fyne.Theme
- func FyneLogo() fyne.Resourcedeprecated
- func GridIcon() fyne.Resource
- func HeaderBackgroundColor() color.Colordeprecated
- func HelpIcon() fyne.Resource
- func HistoryIcon() fyne.Resource
- func HomeIcon() fyne.Resource
- func HoverColor() color.Colordeprecated
- func HyperlinkColor() color.Colordeprecated
- func Icon(name fyne.ThemeIconName) fyne.Resource
- func IconForWidget(name fyne.ThemeIconName, w fyne.Widget) fyne.Resource
- func IconInlineSize() float32
- func InfoIcon() fyne.Resource
- func InnerPadding() float32
- func InputBackgroundColor() color.Colordeprecated
- func InputBorderColor() color.Colordeprecated
- func InputBorderSize() float32
- func InputRadiusSize() float32
- func LightTheme() fyne.Themedeprecated
- func LineSpacing() float32
- func ListIcon() fyne.Resource
- func LoginIcon() fyne.Resource
- func LogoutIcon() fyne.Resource
- func MailAttachmentIcon() fyne.Resource
- func MailComposeIcon() fyne.Resource
- func MailForwardIcon() fyne.Resource
- func MailReplyAllIcon() fyne.Resource
- func MailReplyIcon() fyne.Resource
- func MailSendIcon() fyne.Resource
- func MediaFastForwardIcon() fyne.Resource
- func MediaFastRewindIcon() fyne.Resource
- func MediaMusicIcon() fyne.Resource
- func MediaPauseIcon() fyne.Resource
- func MediaPhotoIcon() fyne.Resource
- func MediaPlayIcon() fyne.Resource
- func MediaRecordIcon() fyne.Resource
- func MediaReplayIcon() fyne.Resource
- func MediaSkipNextIcon() fyne.Resource
- func MediaSkipPreviousIcon() fyne.Resource
- func MediaStopIcon() fyne.Resource
- func MediaVideoIcon() fyne.Resource
- func MenuBackgroundColor() color.Colordeprecated
- func MenuDropDownIcon() fyne.Resource
- func MenuDropUpIcon() fyne.Resource
- func MenuExpandIcon() fyne.Resource
- func MenuIcon() fyne.Resource
- func MoreHorizontalIcon() fyne.Resource
- func MoreVerticalIcon() fyne.Resource
- func MoveDownIcon() fyne.Resource
- func MoveUpIcon() fyne.Resource
- func NavigateBackIcon() fyne.Resource
- func NavigateNextIcon() fyne.Resource
- func OverlayBackgroundColor() color.Colordeprecated
- func Padding() float32
- func PlaceHolderColor() color.Colordeprecated
- func PressedColor() color.Colordeprecated
- func PrimaryColor() color.Colordeprecated
- func PrimaryColorNamed(name string) color.Colordeprecated
- func PrimaryColorNames() []string
- func QuestionIcon() fyne.Resource
- func RadioButtonCheckedIcon() fyne.Resource
- func RadioButtonFillIcon() fyne.Resource
- func RadioButtonIcon() fyne.Resource
- func ScrollBarColor() color.Colordeprecated
- func ScrollBarSize() float32
- func ScrollBarSmallSize() float32
- func SearchIcon() fyne.Resource
- func SearchReplaceIcon() fyne.Resource
- func SelectionColor() color.Colordeprecated
- func SelectionRadiusSize() float32
- func SeparatorColor() color.Colordeprecated
- func SeparatorThicknessSize() float32
- func SettingsIcon() fyne.Resource
- func ShadowColor() color.Colordeprecated
- func Size(name fyne.ThemeSizeName) float32
- func SizeForWidget(name fyne.ThemeSizeName, w fyne.Widget) float32
- func StorageIcon() fyne.Resource
- func SuccessColor() color.Colordeprecated
- func SymbolFont() fyne.Resource
- func TextBoldFont() fyne.Resource
- func TextBoldItalicFont() fyne.Resource
- func TextColor() color.Colordeprecated
- func TextFont() fyne.Resource
- func TextHeadingSize() float32
- func TextItalicFont() fyne.Resource
- func TextMonospaceFont() fyne.Resource
- func TextSize() float32
- func TextSubHeadingSize() float32
- func UploadIcon() fyne.Resource
- func ViewFullScreenIcon() fyne.Resource
- func ViewRefreshIcon() fyne.Resource
- func ViewRestoreIcon() fyne.Resource
- func VisibilityIcon() fyne.Resource
- func VisibilityOffIcon() fyne.Resource
- func VolumeDownIcon() fyne.Resource
- func VolumeMuteIcon() fyne.Resource
- func VolumeUpIcon() fyne.Resource
- func WarningColor() color.Colordeprecated
- func WarningIcon() fyne.Resource
- func WindowCloseIcon() fyne.Resource
- func WindowMaximizeIcon() fyne.Resource
- func WindowMinimizeIcon() fyne.Resource
- func ZoomFitIcon() fyne.Resource
- func ZoomInIcon() fyne.Resource
- func ZoomOutIcon() fyne.Resource
- type DisabledResource
- type ErrorThemedResource
- type InvertedThemedResource
- type PrimaryThemedResource
- type ThemedResource
Constants ¶
const ( // ColorRed is the red primary color name. // // Since: 1.4 ColorRed = internaltheme.ColorRed // ColorOrange is the orange primary color name. // // Since: 1.4 ColorOrange = internaltheme.ColorOrange // ColorYellow is the yellow primary color name. // // Since: 1.4 ColorYellow = internaltheme.ColorYellow // ColorGreen is the green primary color name. // // Since: 1.4 ColorGreen = internaltheme.ColorGreen // ColorBlue is the blue primary color name. // // Since: 1.4 ColorBlue = internaltheme.ColorBlue // ColorPurple is the purple primary color name. // // Since: 1.4 ColorPurple = internaltheme.ColorPurple // ColorBrown is the brown primary color name. // // Since: 1.4 ColorBrown = internaltheme.ColorBrown // ColorGray is the gray primary color name. // // Since: 1.4 ColorGray = internaltheme.ColorGray // ColorNameBackground is the name of theme lookup for background color. // // Since: 2.0 ColorNameBackground fyne.ThemeColorName = "background" // ColorNameButton is the name of theme lookup for button color. // // Since: 2.0 ColorNameButton fyne.ThemeColorName = "button" // ColorNameDisabledButton is the name of theme lookup for disabled button color. // // Since: 2.0 ColorNameDisabledButton fyne.ThemeColorName = "disabledButton" // ColorNameDisabled is the name of theme lookup for disabled foreground color. // // Since: 2.0 ColorNameDisabled fyne.ThemeColorName = "disabled" // ColorNameError is the name of theme lookup for error color. // // Since: 2.0 ColorNameError fyne.ThemeColorName = "error" // ColorNameFocus is the name of theme lookup for focus color. // // Since: 2.0 ColorNameFocus fyne.ThemeColorName = "focus" // ColorNameForeground is the name of theme lookup for foreground color. // // Since: 2.0 ColorNameForeground fyne.ThemeColorName = "foreground" // ColorNameForegroundOnError is the name of theme lookup for a contrast color to the error color. // // Since: 2.5 ColorNameForegroundOnError fyne.ThemeColorName = "foregroundOnError" // ColorNameForegroundOnPrimary is the name of theme lookup for a contrast color to the primary color. // // Since: 2.5 ColorNameForegroundOnPrimary fyne.ThemeColorName = "foregroundOnPrimary" // ColorNameForegroundOnSuccess is the name of theme lookup for a contrast color to the success color. // // Since: 2.5 ColorNameForegroundOnSuccess fyne.ThemeColorName = "foregroundOnSuccess" // ColorNameForegroundOnWarning is the name of theme lookup for a contrast color to the warning color. // // Since: 2.5 ColorNameForegroundOnWarning fyne.ThemeColorName = "foregroundOnWarning" // ColorNameHeaderBackground is the name of theme lookup for background color of a collection header. // // Since: 2.4 ColorNameHeaderBackground fyne.ThemeColorName = "headerBackground" // ColorNameHover is the name of theme lookup for hover color. // // Since: 2.0 ColorNameHover fyne.ThemeColorName = "hover" // ColorNameHyperlink is the name of theme lookup for hyperlink color. // // Since: 2.4 ColorNameHyperlink fyne.ThemeColorName = "hyperlink" // ColorNameInputBackground is the name of theme lookup for background color of an input field. // // Since: 2.0 ColorNameInputBackground fyne.ThemeColorName = "inputBackground" // ColorNameInputBorder is the name of theme lookup for border color of an input field. // // Since: 2.3 ColorNameInputBorder fyne.ThemeColorName = "inputBorder" // ColorNameMenuBackground is the name of theme lookup for background color of menus. // // Since: 2.3 ColorNameMenuBackground fyne.ThemeColorName = "menuBackground" // ColorNameOverlayBackground is the name of theme lookup for background color of overlays like dialogs. // // Since: 2.3 ColorNameOverlayBackground fyne.ThemeColorName = "overlayBackground" // ColorNamePlaceHolder is the name of theme lookup for placeholder text color. // // Since: 2.0 ColorNamePlaceHolder fyne.ThemeColorName = "placeholder" // ColorNamePressed is the name of theme lookup for the tap overlay color. // // Since: 2.0 ColorNamePressed fyne.ThemeColorName = "pressed" // ColorNamePrimary is the name of theme lookup for primary color. // // Since: 2.0 ColorNamePrimary fyne.ThemeColorName = "primary" // ColorNameScrollBar is the name of theme lookup for scrollbar color. // // Since: 2.0 ColorNameScrollBar fyne.ThemeColorName = "scrollBar" // ColorNameScrollBarBackground is the name of theme lookup for scrollbar background color. // // Since: 2.6 ColorNameScrollBarBackground fyne.ThemeColorName = "scrollBarBackground" // ColorNameSelection is the name of theme lookup for selection color. // // Since: 2.1 ColorNameSelection fyne.ThemeColorName = "selection" // ColorNameSeparator is the name of theme lookup for separator bars. // // Since: 2.3 ColorNameSeparator fyne.ThemeColorName = "separator" // ColorNameShadow is the name of theme lookup for shadow color. // // Since: 2.0 ColorNameShadow fyne.ThemeColorName = "shadow" // ColorNameSuccess is the name of theme lookup for success color. // // Since: 2.3 ColorNameSuccess fyne.ThemeColorName = "success" // ColorNameWarning is the name of theme lookup for warning color. // // Since: 2.3 ColorNameWarning fyne.ThemeColorName = "warning" )
Keep in mind to add new constants to the tests at test/theme.go.
const ( // IconNameCancel is the name of theme lookup for cancel icon. // // Since: 2.0 IconNameCancel fyne.ThemeIconName = "cancel" // IconNameConfirm is the name of theme lookup for confirm icon. // // Since: 2.0 IconNameConfirm fyne.ThemeIconName = "confirm" // IconNameDelete is the name of theme lookup for delete icon. // // Since: 2.0 IconNameDelete fyne.ThemeIconName = "delete" // IconNameSearch is the name of theme lookup for search icon. // // Since: 2.0 IconNameSearch fyne.ThemeIconName = "search" // IconNameSearchReplace is the name of theme lookup for search and replace icon. // // Since: 2.0 IconNameSearchReplace fyne.ThemeIconName = "searchReplace" // IconNameMenu is the name of theme lookup for menu icon. // // Since: 2.0 IconNameMenu fyne.ThemeIconName = "menu" // IconNameMenuExpand is the name of theme lookup for menu expansion icon. // // Since: 2.0 IconNameMenuExpand fyne.ThemeIconName = "menuExpand" // IconNameCheckButton is the name of theme lookup for unchecked check button icon. // // Since: 2.0 IconNameCheckButton fyne.ThemeIconName = "unchecked" // IconNameCheckButtonChecked is the name of theme lookup for checked check button icon. // // Since: 2.0 IconNameCheckButtonChecked fyne.ThemeIconName = "checked" // IconNameCheckButtonFill is the name of theme lookup for filled check button icon. // // Since: 2.5 IconNameCheckButtonFill fyne.ThemeIconName = "iconNameCheckButtonFill" // IconNameCheckButtonPartial is the name of theme lookup for "partially" checked check button icon. // // Since: 2.6 IconNameCheckButtonPartial fyne.ThemeIconName = "partial" // IconNameRadioButton is the name of theme lookup for radio button unchecked icon. // // Since: 2.0 IconNameRadioButton fyne.ThemeIconName = "radioButton" // IconNameRadioButtonChecked is the name of theme lookup for radio button checked icon. // // Since: 2.0 IconNameRadioButtonChecked fyne.ThemeIconName = "radioButtonChecked" // IconNameRadioButtonFill is the name of theme lookup for filled radio button icon. // // Since: 2.5 IconNameRadioButtonFill fyne.ThemeIconName = "iconNameRadioButtonFill" // IconNameColorAchromatic is the name of theme lookup for greyscale color icon. // // Since: 2.0 IconNameColorAchromatic fyne.ThemeIconName = "colorAchromatic" // IconNameColorChromatic is the name of theme lookup for full color icon. // // Since: 2.0 IconNameColorChromatic fyne.ThemeIconName = "colorChromatic" // IconNameColorPalette is the name of theme lookup for color palette icon. // // Since: 2.0 IconNameColorPalette fyne.ThemeIconName = "colorPalette" // IconNameContentAdd is the name of theme lookup for content add icon. // // Since: 2.0 IconNameContentAdd fyne.ThemeIconName = "contentAdd" // IconNameContentRemove is the name of theme lookup for content remove icon. // // Since: 2.0 IconNameContentRemove fyne.ThemeIconName = "contentRemove" // IconNameContentCut is the name of theme lookup for content cut icon. // // Since: 2.0 IconNameContentCut fyne.ThemeIconName = "contentCut" // IconNameContentCopy is the name of theme lookup for content copy icon. // // Since: 2.0 IconNameContentCopy fyne.ThemeIconName = "contentCopy" // IconNameContentPaste is the name of theme lookup for content paste icon. // // Since: 2.0 IconNameContentPaste fyne.ThemeIconName = "contentPaste" // IconNameContentClear is the name of theme lookup for content clear icon. // // Since: 2.0 IconNameContentClear fyne.ThemeIconName = "contentClear" // IconNameContentRedo is the name of theme lookup for content redo icon. // // Since: 2.0 IconNameContentRedo fyne.ThemeIconName = "contentRedo" // IconNameContentUndo is the name of theme lookup for content undo icon. // // Since: 2.0 IconNameContentUndo fyne.ThemeIconName = "contentUndo" // IconNameInfo is the name of theme lookup for info icon. // // Since: 2.0 IconNameInfo fyne.ThemeIconName = "info" // IconNameQuestion is the name of theme lookup for question icon. // // Since: 2.0 IconNameQuestion fyne.ThemeIconName = "question" // IconNameWarning is the name of theme lookup for warning icon. // // Since: 2.0 IconNameWarning fyne.ThemeIconName = "warning" // IconNameError is the name of theme lookup for error icon. // // Since: 2.0 IconNameError fyne.ThemeIconName = "error" // IconNameBrokenImage is the name of the theme lookup for broken-image icon. // // Since: 2.4 IconNameBrokenImage fyne.ThemeIconName = "broken-image" // IconNameDocument is the name of theme lookup for document icon. // // Since: 2.0 IconNameDocument fyne.ThemeIconName = "document" // IconNameDocumentCreate is the name of theme lookup for document create icon. // // Since: 2.0 IconNameDocumentCreate fyne.ThemeIconName = "documentCreate" // IconNameDocumentPrint is the name of theme lookup for document print icon. // // Since: 2.0 IconNameDocumentPrint fyne.ThemeIconName = "documentPrint" // IconNameDocumentSave is the name of theme lookup for document save icon. // // Since: 2.0 IconNameDocumentSave fyne.ThemeIconName = "documentSave" // IconNameDragCornerIndicator is the name of the icon used in inner windows to indicate a draggable corner. // // Since: 2.5 IconNameDragCornerIndicator fyne.ThemeIconName = "dragCornerIndicator" // IconNameMoreHorizontal is the name of theme lookup for horizontal more. // // Since 2.0 IconNameMoreHorizontal fyne.ThemeIconName = "moreHorizontal" // IconNameMoreVertical is the name of theme lookup for vertical more. // // Since 2.0 IconNameMoreVertical fyne.ThemeIconName = "moreVertical" // IconNameMailAttachment is the name of theme lookup for mail attachment icon. // // Since: 2.0 IconNameMailAttachment fyne.ThemeIconName = "mailAttachment" // IconNameMailCompose is the name of theme lookup for mail compose icon. // // Since: 2.0 IconNameMailCompose fyne.ThemeIconName = "mailCompose" // IconNameMailForward is the name of theme lookup for mail forward icon. // // Since: 2.0 IconNameMailForward fyne.ThemeIconName = "mailForward" // IconNameMailReply is the name of theme lookup for mail reply icon. // // Since: 2.0 IconNameMailReply fyne.ThemeIconName = "mailReply" // IconNameMailReplyAll is the name of theme lookup for mail reply-all icon. // // Since: 2.0 IconNameMailReplyAll fyne.ThemeIconName = "mailReplyAll" // IconNameMailSend is the name of theme lookup for mail send icon. // // Since: 2.0 IconNameMailSend fyne.ThemeIconName = "mailSend" // IconNameMediaMusic is the name of theme lookup for media music icon. // // Since: 2.1 IconNameMediaMusic fyne.ThemeIconName = "mediaMusic" // IconNameMediaPhoto is the name of theme lookup for media photo icon. // // Since: 2.1 IconNameMediaPhoto fyne.ThemeIconName = "mediaPhoto" // IconNameMediaVideo is the name of theme lookup for media video icon. // // Since: 2.1 IconNameMediaVideo fyne.ThemeIconName = "mediaVideo" // IconNameMediaFastForward is the name of theme lookup for media fast-forward icon. // // Since: 2.0 IconNameMediaFastForward fyne.ThemeIconName = "mediaFastForward" // IconNameMediaFastRewind is the name of theme lookup for media fast-rewind icon. // // Since: 2.0 IconNameMediaFastRewind fyne.ThemeIconName = "mediaFastRewind" // IconNameMediaPause is the name of theme lookup for media pause icon. // // Since: 2.0 IconNameMediaPause fyne.ThemeIconName = "mediaPause" // IconNameMediaPlay is the name of theme lookup for media play icon. // // Since: 2.0 IconNameMediaPlay fyne.ThemeIconName = "mediaPlay" // IconNameMediaRecord is the name of theme lookup for media record icon. // // Since: 2.0 IconNameMediaRecord fyne.ThemeIconName = "mediaRecord" // IconNameMediaReplay is the name of theme lookup for media replay icon. // // Since: 2.0 IconNameMediaReplay fyne.ThemeIconName = "mediaReplay" // IconNameMediaSkipNext is the name of theme lookup for media skip next icon. // // Since: 2.0 IconNameMediaSkipNext fyne.ThemeIconName = "mediaSkipNext" // IconNameMediaSkipPrevious is the name of theme lookup for media skip previous icon. // // Since: 2.0 IconNameMediaSkipPrevious fyne.ThemeIconName = "mediaSkipPrevious" // IconNameMediaStop is the name of theme lookup for media stop icon. // // Since: 2.0 IconNameMediaStop fyne.ThemeIconName = "mediaStop" // IconNameMoveDown is the name of theme lookup for move down icon. // // Since: 2.0 IconNameMoveDown fyne.ThemeIconName = "arrowDown" // IconNameMoveUp is the name of theme lookup for move up icon. // // Since: 2.0 IconNameMoveUp fyne.ThemeIconName = "arrowUp" // // Since: 2.0 IconNameNavigateBack fyne.ThemeIconName = "arrowBack" // // Since: 2.0 IconNameNavigateNext fyne.ThemeIconName = "arrowForward" // IconNameArrowDropDown is the name of theme lookup for drop-down arrow icon. // // Since: 2.0 IconNameArrowDropDown fyne.ThemeIconName = "arrowDropDown" // IconNameArrowDropUp is the name of theme lookup for drop-up arrow icon. // // Since: 2.0 IconNameArrowDropUp fyne.ThemeIconName = "arrowDropUp" // IconNameFile is the name of theme lookup for file icon. // // Since: 2.0 IconNameFile fyne.ThemeIconName = "file" // IconNameFileApplication is the name of theme lookup for file application icon. // // Since: 2.0 IconNameFileApplication fyne.ThemeIconName = "fileApplication" // IconNameFileAudio is the name of theme lookup for file audio icon. // // Since: 2.0 IconNameFileAudio fyne.ThemeIconName = "fileAudio" // IconNameFileImage is the name of theme lookup for file image icon. // // Since: 2.0 IconNameFileImage fyne.ThemeIconName = "fileImage" // IconNameFileText is the name of theme lookup for file text icon. // // Since: 2.0 IconNameFileText fyne.ThemeIconName = "fileText" // IconNameFileVideo is the name of theme lookup for file video icon. // // Since: 2.0 IconNameFileVideo fyne.ThemeIconName = "fileVideo" // IconNameFolder is the name of theme lookup for folder icon. // // Since: 2.0 IconNameFolder fyne.ThemeIconName = "folder" // IconNameFolderNew is the name of theme lookup for folder new icon. // // Since: 2.0 IconNameFolderNew fyne.ThemeIconName = "folderNew" // IconNameFolderOpen is the name of theme lookup for folder open icon. // // Since: 2.0 IconNameFolderOpen fyne.ThemeIconName = "folderOpen" // IconNameHelp is the name of theme lookup for help icon. // // Since: 2.0 IconNameHelp fyne.ThemeIconName = "help" // IconNameHistory is the name of theme lookup for history icon. // // Since: 2.0 IconNameHistory fyne.ThemeIconName = "history" // IconNameHome is the name of theme lookup for home icon. // // Since: 2.0 IconNameHome fyne.ThemeIconName = "home" // IconNameSettings is the name of theme lookup for settings icon. // // Since: 2.0 IconNameSettings fyne.ThemeIconName = "settings" // IconNameStorage is the name of theme lookup for storage icon. // // Since: 2.0 IconNameStorage fyne.ThemeIconName = "storage" // IconNameUpload is the name of theme lookup for upload icon. // // Since: 2.0 IconNameUpload fyne.ThemeIconName = "upload" // IconNameViewFullScreen is the name of theme lookup for view fullscreen icon. // // Since: 2.0 IconNameViewFullScreen fyne.ThemeIconName = "viewFullScreen" // IconNameViewRefresh is the name of theme lookup for view refresh icon. // // Since: 2.0 IconNameViewRefresh fyne.ThemeIconName = "viewRefresh" // IconNameViewZoomFit is the name of theme lookup for view zoom fit icon. // // Since: 2.0 IconNameViewZoomFit fyne.ThemeIconName = "viewZoomFit" // IconNameViewZoomIn is the name of theme lookup for view zoom in icon. // // Since: 2.0 IconNameViewZoomIn fyne.ThemeIconName = "viewZoomIn" // IconNameViewZoomOut is the name of theme lookup for view zoom out icon. // // Since: 2.0 IconNameViewZoomOut fyne.ThemeIconName = "viewZoomOut" // IconNameViewRestore is the name of theme lookup for view restore icon. // // Since: 2.0 IconNameViewRestore fyne.ThemeIconName = "viewRestore" // IconNameVisibility is the name of theme lookup for visibility icon. // // Since: 2.0 IconNameVisibility fyne.ThemeIconName = "visibility" // IconNameVisibilityOff is the name of theme lookup for invisibility icon. // // Since: 2.0 IconNameVisibilityOff fyne.ThemeIconName = "visibilityOff" // IconNameVolumeDown is the name of theme lookup for volume down icon. // // Since: 2.0 IconNameVolumeDown fyne.ThemeIconName = "volumeDown" // IconNameVolumeMute is the name of theme lookup for volume mute icon. // // Since: 2.0 IconNameVolumeMute fyne.ThemeIconName = "volumeMute" // IconNameVolumeUp is the name of theme lookup for volume up icon. // // Since: 2.0 IconNameVolumeUp fyne.ThemeIconName = "volumeUp" // IconNameDownload is the name of theme lookup for download icon. // // Since: 2.0 IconNameDownload fyne.ThemeIconName = "download" // IconNameComputer is the name of theme lookup for computer icon. // // Since: 2.0 IconNameComputer fyne.ThemeIconName = "computer" // IconNameDesktop is the name of theme lookup for desktop icon. // // Since: 2.5 IconNameDesktop fyne.ThemeIconName = "desktop" // IconNameAccount is the name of theme lookup for account icon. // // Since: 2.1 IconNameAccount fyne.ThemeIconName = "account" // IconNameCalendar is the name of theme lookup for calendar icon. // // Since: 2.6 IconNameCalendar fyne.ThemeIconName = "calendar" // IconNameLogin is the name of theme lookup for login icon. // // Since: 2.1 IconNameLogin fyne.ThemeIconName = "login" // IconNameLogout is the name of theme lookup for logout icon. // // Since: 2.1 IconNameLogout fyne.ThemeIconName = "logout" // IconNameList is the name of theme lookup for list icon. // // Since: 2.1 IconNameList fyne.ThemeIconName = "list" // IconNameGrid is the name of theme lookup for grid icon. // // Since: 2.1 IconNameGrid fyne.ThemeIconName = "grid" // IconNameWindowClose is the name of theme lookup for window close icon. // // Since: 2.5 IconNameWindowClose fyne.ThemeIconName = "windowClose" // IconNameWindowMaximize is the name of theme lookup for window maximize icon. // // Since: 2.5 IconNameWindowMaximize fyne.ThemeIconName = "windowMaximize" // IconNameWindowMinimize is the name of theme lookup for window minimize icon. // // Since: 2.5 IconNameWindowMinimize fyne.ThemeIconName = "windowMinimize" )
const ( // SizeNameCaptionText is the name of theme lookup for helper text size, normally smaller than regular text size. // // Since: 2.0 SizeNameCaptionText fyne.ThemeSizeName = "helperText" // SizeNameInlineIcon is the name of theme lookup for inline icons size. // // Since: 2.0 SizeNameInlineIcon fyne.ThemeSizeName = "iconInline" // SizeNameInnerPadding is the name of theme lookup for internal widget padding size. // // Since: 2.3 SizeNameInnerPadding fyne.ThemeSizeName = "innerPadding" // SizeNameLineSpacing is the name of theme lookup for between text line spacing. // // Since: 2.3 SizeNameLineSpacing fyne.ThemeSizeName = "lineSpacing" // SizeNamePadding is the name of theme lookup for padding size. // // Since: 2.0 SizeNamePadding fyne.ThemeSizeName = "padding" // SizeNameScrollBar is the name of theme lookup for the scrollbar size. // // Since: 2.0 SizeNameScrollBar fyne.ThemeSizeName = "scrollBar" // SizeNameScrollBarSmall is the name of theme lookup for the shrunk scrollbar size. // // Since: 2.0 SizeNameScrollBarSmall fyne.ThemeSizeName = "scrollBarSmall" // SizeNameSeparatorThickness is the name of theme lookup for the thickness of a separator. // // Since: 2.0 SizeNameSeparatorThickness fyne.ThemeSizeName = "separator" // SizeNameText is the name of theme lookup for text size. // // Since: 2.0 SizeNameText fyne.ThemeSizeName = "text" // SizeNameHeadingText is the name of theme lookup for text size of a heading. // // Since: 2.1 SizeNameHeadingText fyne.ThemeSizeName = "headingText" // SizeNameSubHeadingText is the name of theme lookup for text size of a sub-heading. // // Since: 2.1 SizeNameSubHeadingText fyne.ThemeSizeName = "subHeadingText" // SizeNameInputBorder is the name of theme lookup for input border size. // // Since: 2.0 SizeNameInputBorder fyne.ThemeSizeName = "inputBorder" // SizeNameInputRadius is the name of theme lookup for input corner radius. // // Since: 2.4 SizeNameInputRadius fyne.ThemeSizeName = "inputRadius" // SizeNameSelectionRadius is the name of theme lookup for selection corner radius. // // Since: 2.4 SizeNameSelectionRadius fyne.ThemeSizeName = "selectionRadius" // SizeNameScrollBarRadius is the name of theme lookup for the scroll bar corner radius. // // Since: 2.5 SizeNameScrollBarRadius fyne.ThemeSizeName = "scrollBarRadius" // SizeNameWindowButtonHeight is the name of the height for an inner window titleBar button. // // Since: 2.6 SizeNameWindowButtonHeight fyne.ThemeSizeName = "windowButtonHeight" // SizeNameWindowButtonRadius is the name of the radius for an inner window titleBar button. // // Since: 2.6 SizeNameWindowButtonRadius fyne.ThemeSizeName = "windowButtonRadius" // SizeNameWindowButtonIcon is the name of the width of an inner window titleBar button. // // Since: 2.6 SizeNameWindowButtonIcon fyne.ThemeSizeName = "windowButtonIcon" // SizeNameWindowTitleBarHeight is the height for inner window titleBars. // // Since: 2.6 SizeNameWindowTitleBarHeight fyne.ThemeSizeName = "windowTitleBarHeight" )
const ( // VariantDark is the version of a theme that satisfies a user preference for a dark look. // // Since: 2.0 VariantDark = internaltheme.VariantDark // VariantLight is the version of a theme that satisfies a user preference for a light look. // // Since: 2.0 VariantLight = internaltheme.VariantLight )
Keep in mind to add new constants to the tests at test/theme.go.
Variables ¶
This section is empty.
Functions ¶
func AccountIcon ¶ added in v2.1.0
AccountIcon returns a resource containing the standard account icon for the current theme
func BackgroundColor
deprecated
func BrokenImageIcon ¶ added in v2.4.0
BrokenImageIcon returns a resource containing an icon to specify a broken or missing image
Since: 2.4
func ButtonColor
deprecated
func CalendarIcon ¶ added in v2.6.0
CalendarIcon returns a resource containing the standard account icon for the current theme
Since: 2.6
func CancelIcon ¶
CancelIcon returns a resource containing the standard cancel icon for the current theme
func CaptionTextSize ¶
func CaptionTextSize() float32
CaptionTextSize returns the size for caption text.
func CheckButtonCheckedIcon ¶
CheckButtonCheckedIcon returns a resource containing the standard checkbox checked icon for the current theme
func CheckButtonFillIcon ¶ added in v2.5.0
CheckButtonFillIcon returns a resource containing the filled checkbox icon for the current theme.
Since: 2.5
func CheckButtonIcon ¶
CheckButtonIcon returns a resource containing the standard checkbox icon for the current theme
func Color ¶ added in v2.5.0
func Color(name fyne.ThemeColorName) color.Color
Color looks up the named colour for current theme and variant.
Since: 2.5
func ColorAchromaticIcon ¶
ColorAchromaticIcon returns a resource containing the standard achromatic color icon for the current theme
func ColorChromaticIcon ¶
ColorChromaticIcon returns a resource containing the standard chromatic color icon for the current theme
func ColorForWidget ¶ added in v2.5.0
ColorForWidget looks up the named colour for the requested widget using the current theme and variant. If the widget theme has been overridden that theme will be used.
Since: 2.5
func ColorPaletteIcon ¶
ColorPaletteIcon returns a resource containing the standard color palette icon for the current theme
func ComputerIcon ¶
ComputerIcon returns a resource containing the standard computer icon for the current theme
func ConfirmIcon ¶
ConfirmIcon returns a resource containing the standard confirm icon for the current theme
func ContentAddIcon ¶
ContentAddIcon returns a resource containing the standard content add icon for the current theme
func ContentClearIcon ¶
ContentClearIcon returns a resource containing the standard content clear icon for the current theme
func ContentCopyIcon ¶
ContentCopyIcon returns a resource containing the standard content copy icon for the current theme
func ContentCutIcon ¶
ContentCutIcon returns a resource containing the standard content cut icon for the current theme
func ContentPasteIcon ¶
ContentPasteIcon returns a resource containing the standard content paste icon for the current theme
func ContentRedoIcon ¶
ContentRedoIcon returns a resource containing the standard content redo icon for the current theme
func ContentRemoveIcon ¶
ContentRemoveIcon returns a resource containing the standard content remove icon for the current theme
func ContentUndoIcon ¶
ContentUndoIcon returns a resource containing the standard content undo icon for the current theme
func Current ¶ added in v2.5.0
Current returns the theme that is currently used for the running application. It looks up based on user preferences and application configuration.
Since: 2.5
func CurrentForWidget ¶ added in v2.5.0
func CurrentForWidget(w fyne.CanvasObject) fyne.Theme
CurrentForWidget returns the theme that is currently used for the specified widget. It looks for widget overrides and falls back to the application's current theme.
Since: 2.5
func DarkTheme
deprecated
func DefaultEmojiFont ¶ added in v2.4.0
DefaultEmojiFont returns the font resource for the built-in emoji font. This may return nil if the application was packaged without an emoji font.
Since: 2.4
func DefaultSymbolFont ¶ added in v2.2.0
DefaultSymbolFont returns the font resource for the built-in symbol font.
Since: 2.2
func DefaultTextBoldFont ¶
DefaultTextBoldFont returns the font resource for the built-in bold font style.
func DefaultTextBoldItalicFont ¶
DefaultTextBoldItalicFont returns the font resource for the built-in bold and italic font style.
func DefaultTextFont ¶
DefaultTextFont returns the font resource for the built-in regular font style.
func DefaultTextItalicFont ¶
DefaultTextItalicFont returns the font resource for the built-in italic font style.
func DefaultTextMonospaceFont ¶
DefaultTextMonospaceFont returns the font resource for the built-in monospace font face.
func DefaultTheme ¶
DefaultTheme returns a built-in theme that can adapt to the user preference of light or dark colors.
Since: 2.0
func DeleteIcon ¶
DeleteIcon returns a resource containing the standard delete icon for the current theme
func DesktopIcon ¶ added in v2.5.0
DesktopIcon returns a resource containing the standard desktop icon for the current theme
func DisabledButtonColor
deprecated
func DisabledColor
deprecated
func DisabledTextColor
deprecated
func DocumentCreateIcon ¶
DocumentCreateIcon returns a resource containing the standard document create icon for the current theme
func DocumentIcon ¶
DocumentIcon returns a resource containing the standard document icon for the current theme
func DocumentPrintIcon ¶
DocumentPrintIcon returns a resource containing the standard document print icon for the current theme
func DocumentSaveIcon ¶
DocumentSaveIcon returns a resource containing the standard document save icon for the current theme
func DownloadIcon ¶
DownloadIcon returns a resource containing the standard download icon for the current theme
func ErrorColor
deprecated
func ErrorIcon ¶
ErrorIcon returns a resource containing the standard dialog error icon for the current theme
func FileApplicationIcon ¶
FileApplicationIcon returns a resource containing the file icon representing application files for the current theme
func FileAudioIcon ¶
FileAudioIcon returns a resource containing the file icon representing audio files for the current theme
func FileIcon ¶
FileIcon returns a resource containing the appropriate file icon for the current theme
func FileImageIcon ¶
FileImageIcon returns a resource containing the file icon representing image files for the current theme
func FileTextIcon ¶
FileTextIcon returns a resource containing the file icon representing text files for the current theme
func FileVideoIcon ¶
FileVideoIcon returns a resource containing the file icon representing video files for the current theme
func FocusColor
deprecated
func FolderIcon ¶
FolderIcon returns a resource containing the standard folder icon for the current theme
func FolderNewIcon ¶
FolderNewIcon returns a resource containing the standard folder creation icon for the current theme
func FolderOpenIcon ¶
FolderOpenIcon returns a resource containing the standard folder open icon for the current theme
func ForegroundColor
deprecated
func FromJSON ¶ added in v2.2.0
FromJSON returns a Theme created from the given JSON metadata. Any values not present in the data will fall back to the default theme. If a parse error occurs it will be returned along with a default theme.
Since: 2.2
func FromJSONReader ¶ added in v2.2.0
FromJSONReader returns a Theme created from the given JSON metadata through the reader. Any values not present in the data will fall back to the default theme. If a parse error occurs it will be returned along with a default theme.
Since: 2.2
func FromJSONReaderWithFallback ¶ added in v2.7.0
FromJSONReaderWithFallback returns a Theme created from the given JSON metadata through the reader. Any values not present in the data will fall back to the specified theme. If a parse error occurs it will be returned along with a specified fallback theme.
Since: 2.7
func FromJSONWithFallback ¶ added in v2.7.0
FromJSONWithFallback returns a Theme created from the given JSON metadata. Any values not present in the data will fall back to the specified theme. If a parse error occurs it will be returned along with a specified fallback theme.
Since: 2.7
func FromLegacy ¶
func FromLegacy(t fyne.LegacyTheme) fyne.Theme
FromLegacy returns a 2.0 Theme created from the given LegacyTheme data. This is a transition path and will be removed in the future (probably version 3.0).
Since: 2.0
func GridIcon ¶ added in v2.1.0
GridIcon returns a resource containing the standard grid icon for the current theme
func HeaderBackgroundColor
deprecated
added in
v2.4.0
func HistoryIcon ¶
HistoryIcon returns a resource containing the standard history icon for the current theme
func HomeIcon ¶
HomeIcon returns a resource containing the standard home folder icon for the current theme
func HoverColor
deprecated
func HyperlinkColor
deprecated
added in
v2.4.0
func Icon ¶ added in v2.5.0
func Icon(name fyne.ThemeIconName) fyne.Resource
Icon looks up the specified icon for current theme.
Since: 2.5
func IconForWidget ¶ added in v2.5.0
IconForWidget looks up the specified icon for requested widget using the current theme. If the widget theme has been overridden that theme will be used.
Since: 2.5
func IconInlineSize ¶
func IconInlineSize() float32
IconInlineSize is the standard size of icons which appear within buttons, labels etc.
func InfoIcon ¶
InfoIcon returns a resource containing the standard dialog info icon for the current theme
func InnerPadding ¶ added in v2.3.0
func InnerPadding() float32
InnerPadding is the standard gap between element content and the outside edge of a widget.
Since: 2.3
func InputBackgroundColor
deprecated
func InputBorderColor
deprecated
added in
v2.3.0
func InputBorderSize ¶
func InputBorderSize() float32
InputBorderSize returns the input border size (or underline size for an entry).
Since: 2.0
func InputRadiusSize ¶ added in v2.4.0
func InputRadiusSize() float32
InputRadiusSize returns the input radius size.
Since: 2.4
func LightTheme
deprecated
func LineSpacing ¶ added in v2.3.0
func LineSpacing() float32
LineSpacing is the default gap between multiple lines of text.
Since: 2.3
func ListIcon ¶ added in v2.1.0
ListIcon returns a resource containing the standard list icon for the current theme
func LoginIcon ¶ added in v2.1.0
LoginIcon returns a resource containing the standard login icon for the current theme
func LogoutIcon ¶ added in v2.1.0
LogoutIcon returns a resource containing the standard logout icon for the current theme
func MailAttachmentIcon ¶
MailAttachmentIcon returns a resource containing the standard mail attachment icon for the current theme
func MailComposeIcon ¶
MailComposeIcon returns a resource containing the standard mail compose icon for the current theme
func MailForwardIcon ¶
MailForwardIcon returns a resource containing the standard mail forward icon for the current theme
func MailReplyAllIcon ¶
MailReplyAllIcon returns a resource containing the standard mail reply all icon for the current theme
func MailReplyIcon ¶
MailReplyIcon returns a resource containing the standard mail reply icon for the current theme
func MailSendIcon ¶
MailSendIcon returns a resource containing the standard mail send icon for the current theme
func MediaFastForwardIcon ¶
MediaFastForwardIcon returns a resource containing the standard media fast-forward icon for the current theme
func MediaFastRewindIcon ¶
MediaFastRewindIcon returns a resource containing the standard media fast-rewind icon for the current theme
func MediaMusicIcon ¶ added in v2.1.0
MediaMusicIcon returns a resource containing the standard media music icon for the current theme
Since: 2.1
func MediaPauseIcon ¶
MediaPauseIcon returns a resource containing the standard media pause icon for the current theme
func MediaPhotoIcon ¶ added in v2.1.0
MediaPhotoIcon returns a resource containing the standard media photo icon for the current theme
Since: 2.1
func MediaPlayIcon ¶
MediaPlayIcon returns a resource containing the standard media play icon for the current theme
func MediaRecordIcon ¶
MediaRecordIcon returns a resource containing the standard media record icon for the current theme
func MediaReplayIcon ¶
MediaReplayIcon returns a resource containing the standard media replay icon for the current theme
func MediaSkipNextIcon ¶
MediaSkipNextIcon returns a resource containing the standard media skip next icon for the current theme
func MediaSkipPreviousIcon ¶
MediaSkipPreviousIcon returns a resource containing the standard media skip previous icon for the current theme
func MediaStopIcon ¶
MediaStopIcon returns a resource containing the standard media stop icon for the current theme
func MediaVideoIcon ¶ added in v2.1.0
MediaVideoIcon returns a resource containing the standard media video icon for the current theme
Since: 2.1
func MenuBackgroundColor
deprecated
added in
v2.3.0
func MenuDropDownIcon ¶
MenuDropDownIcon returns a resource containing the standard menu drop down icon for the current theme
func MenuDropUpIcon ¶
MenuDropUpIcon returns a resource containing the standard menu drop up icon for the current theme
func MenuExpandIcon ¶
MenuExpandIcon returns a resource containing the standard (mobile) expand "submenu icon for the current theme
func MenuIcon ¶
MenuIcon returns a resource containing the standard (mobile) menu icon for the current theme
func MoreHorizontalIcon ¶ added in v2.1.0
MoreHorizontalIcon returns a resource containing the standard horizontal more icon for the current theme
func MoreVerticalIcon ¶ added in v2.1.0
MoreVerticalIcon returns a resource containing the standard vertical more icon for the current theme
func MoveDownIcon ¶
MoveDownIcon returns a resource containing the standard down arrow icon for the current theme
func MoveUpIcon ¶
MoveUpIcon returns a resource containing the standard up arrow icon for the current theme
func NavigateBackIcon ¶
NavigateBackIcon returns a resource containing the standard backward navigation icon for the current theme
func NavigateNextIcon ¶
NavigateNextIcon returns a resource containing the standard forward navigation icon for the current theme
func OverlayBackgroundColor
deprecated
added in
v2.3.0
func Padding ¶
func Padding() float32
Padding is the standard gap between elements and the border around interface elements.
func PlaceHolderColor
deprecated
func PressedColor
deprecated
func PrimaryColor
deprecated
func PrimaryColorNamed
deprecated
func PrimaryColorNames ¶
func PrimaryColorNames() []string
PrimaryColorNames returns a list of the standard primary color options.
Since: 1.4
func QuestionIcon ¶
QuestionIcon returns a resource containing the standard dialog question icon for the current theme
func RadioButtonCheckedIcon ¶
RadioButtonCheckedIcon returns a resource containing the standard radio button checked icon for the current theme
func RadioButtonFillIcon ¶ added in v2.5.0
RadioButtonFillIcon returns a resource containing the filled checkbox icon for the current theme.
Since: 2.5
func RadioButtonIcon ¶
RadioButtonIcon returns a resource containing the standard radio button icon for the current theme
func ScrollBarColor
deprecated
func ScrollBarSize ¶
func ScrollBarSize() float32
ScrollBarSize is the width (or height) of the bars on a ScrollContainer.
func ScrollBarSmallSize ¶
func ScrollBarSmallSize() float32
ScrollBarSmallSize is the width (or height) of the minimized bars on a ScrollContainer.
func SearchIcon ¶
SearchIcon returns a resource containing the standard search icon for the current theme
func SearchReplaceIcon ¶
SearchReplaceIcon returns a resource containing the standard search and replace icon for the current theme
func SelectionColor
deprecated
added in
v2.1.0
func SelectionRadiusSize ¶ added in v2.4.0
func SelectionRadiusSize() float32
SelectionRadiusSize returns the selection highlight radius size.
Since: 2.4
func SeparatorColor
deprecated
added in
v2.3.0
func SeparatorThicknessSize ¶
func SeparatorThicknessSize() float32
SeparatorThicknessSize is the standard thickness of the separator widget.
Since: 2.0
func SettingsIcon ¶
SettingsIcon returns a resource containing the standard settings icon for the current theme
func ShadowColor
deprecated
func Size ¶ added in v2.5.0
func Size(name fyne.ThemeSizeName) float32
Size looks up the specified size for current theme.
Since: 2.5
func SizeForWidget ¶ added in v2.5.0
func SizeForWidget(name fyne.ThemeSizeName, w fyne.Widget) float32
SizeForWidget looks up the specified size for the requested widget using the current theme. If the widget theme has been overridden that theme will be used.
Since: 2.5
func StorageIcon ¶
StorageIcon returns a resource containing the standard storage icon for the current theme
func SuccessColor
deprecated
added in
v2.3.0
func SymbolFont ¶ added in v2.4.0
SymbolFont returns the font resource for the symbol font style.
Since: 2.4
func TextBoldFont ¶
TextBoldFont returns the font resource for the bold font style.
func TextBoldItalicFont ¶
TextBoldItalicFont returns the font resource for the bold and italic font style.
func TextHeadingSize ¶ added in v2.1.0
func TextHeadingSize() float32
TextHeadingSize returns the text size for header text.
Since: 2.1
func TextItalicFont ¶
TextItalicFont returns the font resource for the italic font style.
func TextMonospaceFont ¶
TextMonospaceFont returns the font resource for the monospace font face.
func TextSubHeadingSize ¶ added in v2.1.0
func TextSubHeadingSize() float32
TextSubHeadingSize returns the text size for sub-header text.
Since: 2.1
func UploadIcon ¶
UploadIcon returns a resource containing the standard upload icon for the current theme
func ViewFullScreenIcon ¶
ViewFullScreenIcon returns a resource containing the standard fullscreen icon for the current theme
func ViewRefreshIcon ¶
ViewRefreshIcon returns a resource containing the standard refresh icon for the current theme
func ViewRestoreIcon ¶
ViewRestoreIcon returns a resource containing the standard exit fullscreen icon for the current theme
func VisibilityIcon ¶
VisibilityIcon returns a resource containing the standard visibility icon for the current theme
func VisibilityOffIcon ¶
VisibilityOffIcon returns a resource containing the standard visibility off icon for the current theme
func VolumeDownIcon ¶
VolumeDownIcon returns a resource containing the standard volume down icon for the current theme
func VolumeMuteIcon ¶
VolumeMuteIcon returns a resource containing the standard volume mute icon for the current theme
func VolumeUpIcon ¶
VolumeUpIcon returns a resource containing the standard volume up icon for the current theme
func WarningColor
deprecated
added in
v2.3.0
func WarningIcon ¶
WarningIcon returns a resource containing the standard dialog warning icon for the current theme
func WindowCloseIcon ¶ added in v2.5.0
WindowCloseIcon returns a resource containing the window close icon for the current theme
Since: 2.5
func WindowMaximizeIcon ¶ added in v2.5.0
WindowMaximizeIcon returns a resource containing the window maximize icon for the current theme
Since: 2.5
func WindowMinimizeIcon ¶ added in v2.5.0
WindowMinimizeIcon returns a resource containing the window minimize icon for the current theme
Since: 2.5
func ZoomFitIcon ¶
ZoomFitIcon returns a resource containing the standard zoom fit icon for the current theme
func ZoomInIcon ¶
ZoomInIcon returns a resource containing the standard zoom in icon for the current theme
func ZoomOutIcon ¶
ZoomOutIcon returns a resource containing the standard zoom out icon for the current theme
Types ¶
type DisabledResource ¶
type DisabledResource struct {
// contains filtered or unexported fields
}
DisabledResource is a resource wrapper that will return an appropriate resource colorized by the current theme's `DisabledColor` color.
func NewDisabledResource ¶
func NewDisabledResource(res fyne.Resource) *DisabledResource
NewDisabledResource creates a resource that adapts to the current theme's DisabledColor setting.
func (*DisabledResource) Content ¶
func (res *DisabledResource) Content() []byte
Content returns the disabled style content of the correct resource for the current theme
func (*DisabledResource) Name ¶
func (res *DisabledResource) Name() string
Name returns the resource source name prefixed with `disabled_` (used for caching)
func (*DisabledResource) ThemeColorName ¶ added in v2.6.0
func (res *DisabledResource) ThemeColorName() fyne.ThemeColorName
ThemeColorName returns the fyne.ThemeColorName that is used as foreground color.
Since: 2.6
type ErrorThemedResource ¶
type ErrorThemedResource struct {
// contains filtered or unexported fields
}
ErrorThemedResource is a resource wrapper that will return a version of the resource with the main color changed to indicate an error.
func NewErrorThemedResource ¶
func NewErrorThemedResource(orig fyne.Resource) *ErrorThemedResource
NewErrorThemedResource creates a resource that adapts to the error color for the current theme.
func (*ErrorThemedResource) Content ¶
func (res *ErrorThemedResource) Content() []byte
Content returns the underlying content of the resource adapted to the current background color.
func (*ErrorThemedResource) Name ¶
func (res *ErrorThemedResource) Name() string
Name returns the underlying resource name (used for caching).
func (*ErrorThemedResource) Original ¶
func (res *ErrorThemedResource) Original() fyne.Resource
Original returns the underlying resource that this error themed resource was adapted from
func (*ErrorThemedResource) ThemeColorName ¶ added in v2.6.0
func (res *ErrorThemedResource) ThemeColorName() fyne.ThemeColorName
ThemeColorName returns the fyne.ThemeColorName that is used as foreground color.
Since: 2.6
type InvertedThemedResource ¶
type InvertedThemedResource struct {
// contains filtered or unexported fields
}
InvertedThemedResource is a resource wrapper that will return a version of the resource with the main color changed for use over highlighted elements.
func NewInvertedThemedResource ¶
func NewInvertedThemedResource(orig fyne.Resource) *InvertedThemedResource
NewInvertedThemedResource creates a resource that adapts to the current theme for use over highlighted elements.
func (*InvertedThemedResource) Content ¶
func (res *InvertedThemedResource) Content() []byte
Content returns the underlying content of the resource adapted to the current background color.
func (*InvertedThemedResource) Name ¶
func (res *InvertedThemedResource) Name() string
Name returns the underlying resource name (used for caching).
func (*InvertedThemedResource) Original ¶
func (res *InvertedThemedResource) Original() fyne.Resource
Original returns the underlying resource that this inverted themed resource was adapted from
func (*InvertedThemedResource) ThemeColorName ¶ added in v2.5.0
func (res *InvertedThemedResource) ThemeColorName() fyne.ThemeColorName
ThemeColorName returns the fyne.ThemeColorName that is used as foreground color.
type PrimaryThemedResource ¶
type PrimaryThemedResource struct {
// contains filtered or unexported fields
}
PrimaryThemedResource is a resource wrapper that will return a version of the resource with the main color changed to the theme primary color.
func NewPrimaryThemedResource ¶
func NewPrimaryThemedResource(orig fyne.Resource) *PrimaryThemedResource
NewPrimaryThemedResource creates a resource that adapts to the primary color for the current theme.
func (*PrimaryThemedResource) Content ¶
func (res *PrimaryThemedResource) Content() []byte
Content returns the underlying content of the resource adapted to the current background color.
func (*PrimaryThemedResource) Name ¶
func (res *PrimaryThemedResource) Name() string
Name returns the underlying resource name (used for caching).
func (*PrimaryThemedResource) Original ¶
func (res *PrimaryThemedResource) Original() fyne.Resource
Original returns the underlying resource that this primary themed resource was adapted from
func (*PrimaryThemedResource) ThemeColorName ¶ added in v2.6.0
func (res *PrimaryThemedResource) ThemeColorName() fyne.ThemeColorName
ThemeColorName returns the fyne.ThemeColorName that is used as foreground color.
Since: 2.6
type ThemedResource ¶
type ThemedResource struct {
// ColorName specifies which theme colour should be used to theme the resource
//
// Since: 2.3
ColorName fyne.ThemeColorName
// contains filtered or unexported fields
}
ThemedResource is a resource wrapper that will return a version of the resource with the main color changed for the currently selected theme.
func NewColoredResource ¶ added in v2.4.0
func NewColoredResource(src fyne.Resource, name fyne.ThemeColorName) *ThemedResource
NewColoredResource creates a resource that adapts to the current theme setting using the color named in the constructor.
Since: 2.4
func NewSuccessThemedResource ¶ added in v2.4.0
func NewSuccessThemedResource(src fyne.Resource) *ThemedResource
NewSuccessThemedResource creates a resource that adapts to the current theme success color.
Since: 2.4
func NewThemedResource ¶
func NewThemedResource(src fyne.Resource) *ThemedResource
NewThemedResource creates a resource that adapts to the current theme setting. By default, this will match the foreground color, but it can be changed using the `ColorName` field.
func NewWarningThemedResource ¶ added in v2.4.0
func NewWarningThemedResource(src fyne.Resource) *ThemedResource
NewWarningThemedResource creates a resource that adapts to the current theme warning color.
Since: 2.4
func (*ThemedResource) Content ¶
func (res *ThemedResource) Content() []byte
Content returns the underlying content of the resource adapted to the current text color.
func (*ThemedResource) Error ¶
func (res *ThemedResource) Error() *ErrorThemedResource
Error returns a different resource for indicating an error.
func (*ThemedResource) Name ¶
func (res *ThemedResource) Name() string
Name returns the underlying resource name (used for caching).
func (*ThemedResource) ThemeColorName ¶ added in v2.5.0
func (res *ThemedResource) ThemeColorName() fyne.ThemeColorName
ThemeColorName returns the fyne.ThemeColorName that is used as foreground color.